clear all;
close all;
clc;

%% Read audio file
% [x,fs] = audioread('hootie.wav'); % fs is the sampling frequency
 [x,fs] = audioread('tenorsax.wav');

%% Let's listen to the data
soundsc(x,fs)

%% Plot the audio signal in the time domain
figure(1)
plot(x)
ylabel('Amplitude')
xlabel('Time')

%% Let's plot a small portion to see some details
time=(1/fs)*2000;
t=linspace(0,time,2000);
plot(t,x(1:2000))
xlabel('Time (sec)');
ylabel('Amplitude')

%% Reverse playing just for fun :)
soundsc(flipud(x),fs)

%% Compute the DCT of the audio signal
Y = dct(x);

%% Plot the audio signal in the frequency domain
figure(2)
plot(Y)
ylabel('Amplitude')
xlabel('Frequency (Hz)')

%% Plot sorted coefficients with logarithmic scale
figure(3)
semilogy(sort(Y,'descend'))
ylabel('Amplitude')
xlabel('Frequency (Hz)')

%% Select the largest 30% of the DCT coefficients
thres = prctile(abs(Y),70); % 70th percentile is the value below which 70% of the entries in abs(Y) lie.
Y_thresh = zeros(length(Y),1);
for i = 1:length(Y)
    if abs(Y(i)) > thres 
        Y_thresh(i) = Y(i);
    end
end

%% Compute the audio signal in the time domain after thresholding
x_thresh = idct(Y_thresh);

%% Plot the audio signal in the time domain after thresholding
figure(4)
plot(x_thresh,'r')

%% Plot original signal on top
hold on
plot(x,'b')
ylabel('Amplitude')
xlabel('Time')
hold off

%% Plot the difference of the original signal to the thersholed signal in the time domain 
figure(4)
plot(x-x_thresh,'r')
ylabel('Amplitude')
xlabel('Time')

%% Let's listen to the approximated/thresholded signal
soundsc(x_thresh,fs)

%% Let's listen to the approximation error
soundsc(x-x_thresh,fs)
